# 🌍 [PRODUCT_NAME] Market Research & Competitive Analysis
<!-- Example: Product Kit Market Research, TaskFlow Market Analysis, etc. -->

## Purpose
This document provides market context, competitive intelligence, and strategic positioning to inform product decisions. Use this to validate new features against market trends and competitive landscape.

---

## 1. Market Overview
*What is the state of the industry?*

### Market Size
-   **Total Addressable Market (TAM)**: [TAM_VALUE] ([TAM_DESCRIPTION])
-   **Serviceable Available Market (SAM)**: [SAM_VALUE] ([SAM_DESCRIPTION])
-   **Serviceable Obtainable Market (SOM)**: [SOM_VALUE] ([SOM_DESCRIPTION])

<!-- Example:
-   **Total Addressable Market (TAM)**: $10B (Global SaaS Analytics Market).
-   **Serviceable Available Market (SAM)**: $2B (Mid-market companies in North America).
-->

### Key Trends
-   [TREND_1]
-   [TREND_2]
-   [TREND_3]

<!-- Example:
-   Shift towards "Self-serve" analytics.
-   AI-driven insights are becoming table stakes.
-   Privacy-first data handling (GDPR/CCPA).
-->

---

## 2. Competitive Landscape

### 🥊 Competitor A: [COMPETITOR_1_NAME]
<!-- Example: Market Leader -->
-   **Website**: [WEBSITE_URL]
-   **Value Proposition**: "[VALUE_PROP]"
-   **Strengths**:
    -   [STRENGTH_1]
    -   [STRENGTH_2]
    -   [STRENGTH_3]
-   **Weaknesses**:
    -   [WEAKNESS_1]
    -   [WEAKNESS_2]
    -   [WEAKNESS_3]
-   **Our Strategy**: [DIFFERENTIATION_STRATEGY]

<!-- Example:
-   **Website**: [Link]
-   **Value Proposition**: "The enterprise standard for analytics."
-   **Strengths**:
    -   Robust feature set.
    -   Strong enterprise security compliance.
-   **Weaknesses**:
    -   Expensive ($50k/year min).
    -   Clunky, outdated UI.
    -   Slow implementation (3-6 months).
-   **Our Strategy**: Win on **Time-to-Value** and **UX**. We can get users live in minutes, not months.
-->

### 🥊 Competitor B: [COMPETITOR_2_NAME]
<!-- Example: The Upstart -->
-   **Website**: [WEBSITE_URL]
-   **Value Proposition**: "[VALUE_PROP]"
-   **Strengths**:
    -   [STRENGTH_1]
    -   [STRENGTH_2]
-   **Weaknesses**:
    -   [WEAKNESS_1]
    -   [WEAKNESS_2]
-   **Our Strategy**: [DIFFERENTIATION_STRATEGY]

<!-- Example:
-   **Website**: [Link]
-   **Value Proposition**: "Analytics for startups."
-   **Strengths**:
    -   Beautiful design.
    -   Cheap/Free tier.
-   **Weaknesses**:
    -   Lacks advanced data governance.
    -   Does not scale past 1M events/month.
-   **Our Strategy**: Win on **Scalability** and **Reliability**. We are the "grown-up" choice for scale-ups.
-->

---

## 3. SWOT Analysis

| | Positive | Negative |
| :--- | :--- | :--- |
| **Internal** | **Strengths**<br>[STRENGTH_LIST] | **Weaknesses**<br>[WEAKNESS_LIST] |
| **External** | **Opportunities**<br>[OPPORTUNITY_LIST] | **Threats**<br>[THREAT_LIST] |

<!-- Example:
| **Internal** | **Strengths**<br>- Agile engineering team.<br>- Proprietary data compression algo. | **Weaknesses**<br>- Small marketing budget.<br>- Lack of 24/7 support. |
| **External** | **Opportunities**<br>- Competitor A just raised prices.<br>- New regulation favors our privacy approach. | **Threats**<br>- Big Tech (Google/Microsoft) entering the space.<br>- Economic downturn reducing SaaS spend. |
-->

---

## 4. Market Positioning

### Our Unique Positioning
[POSITIONING_STATEMENT]

<!-- Example: "We are the analytics platform that combines enterprise-grade features with startup-level simplicity, enabling mid-market companies to get insights in minutes, not months." -->

### Target Customer Profile
-   **Industry**: [TARGET_INDUSTRY]
-   **Company Size**: [COMPANY_SIZE]
-   **Geography**: [TARGET_GEOGRAPHY]
-   **Budget Range**: [BUDGET_RANGE]

<!-- Example:
-   **Industry**: SaaS, E-commerce, FinTech
-   **Company Size**: 50-500 employees
-   **Geography**: North America, Europe
-   **Budget Range**: $10k-$100k annually
-->

---

**Version**: [MARKET_RESEARCH_VERSION] | **Last Updated**: [LAST_UPDATED_DATE]
<!-- Example: Version: 1.2.0 | Last Updated: 2026-01-02 -->
